@@ -1,3 +1,2 @@
 # no variables that start with `_` will be included
-from .fetch import *
-from .headers import *
+from .fetch import FetchModule
