@@ -1,2 +1,2 @@
 # import everything that is not prefixed with underscore `_`
-from .snapshot import *
+from .snapshot import SnapshotModule
